## Installation

FLPInspect require Python 3.6+

- Via `pip` [**Recommended**]:

  ```
  pip install --upgrade flpinspect
  ```

- Via GitHub [releases](https://github.com/demberto/FLPInspect/releases)
  - Install required dependencies:
    ```
    pip install -rrequirements.txt
    ```

### Note for Mac users

_Although FLPInspect is cross-platform, Tkinter has some issues with Mac, I don't have a Mac to test myself. **The bugs will only be minor UI bugs at most.**_
